Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(650)

Unified Diff: src/objects.h

Issue 2028983002: Introduce IsUndefined(Isolate*) and IsTheHole(Isolate*) (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: doing proper rebase Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/objects.h
diff --git a/src/objects.h b/src/objects.h
index 371c4854f6108949035c9af8df91575cba9a08fa..7c2159f72cca812bf86420a2b1b912946af08890 100644
--- a/src/objects.h
+++ b/src/objects.h
@@ -1064,6 +1064,9 @@ class Object {
STRUCT_LIST(DECLARE_STRUCT_PREDICATE)
#undef DECLARE_STRUCT_PREDICATE
+ INLINE(bool IsTheHole(Isolate* isolate) const);
+ INLINE(bool IsUndefined(Isolate* isolate) const);
+
// ES6, section 7.2.2 IsArray. NOT to be confused with %_IsArray.
MUST_USE_RESULT static Maybe<bool> IsArray(Handle<Object> object);
@@ -1560,6 +1563,9 @@ class HeapObject: public Object {
STRUCT_LIST(DECLARE_STRUCT_PREDICATE)
#undef DECLARE_STRUCT_PREDICATE
+ INLINE(bool IsTheHole(Isolate* isolate) const);
Michael Starzinger 2016/06/06 08:55:08 The predicates are already declared on the {Object
+ INLINE(bool IsUndefined(Isolate* isolate) const);
+
// Converts an address to a HeapObject pointer.
static inline HeapObject* FromAddress(Address address) {
DCHECK_TAG_ALIGNED(address);
@@ -3875,7 +3881,7 @@ class OrderedHashTable: public FixedArray {
int KeyToFirstEntry(Object* key) {
Object* hash = key->GetHash();
// If the object does not have an identity hash, it was never used as a key
- if (hash->IsUndefined()) return kNotFound;
+ if (hash->IsUndefined(GetIsolate())) return kNotFound;
return HashToEntry(Smi::cast(hash)->value());
}
@@ -3884,7 +3890,7 @@ class OrderedHashTable: public FixedArray {
return Smi::cast(next_entry)->value();
}
// use KeyAt(i)->IsTheHole() to determine if this is a deleted entry.
Object* KeyAt(int entry) {
DCHECK_LT(entry, this->UsedCapacity());
return get(EntryToIndex(entry));
@@ -3884,7 +3890,7 @@ class OrderedHashTable: public FixedArray {
return Smi::cast(next_entry)->value();
}
- // use KeyAt(i)->IsTheHole() to determine if this is a deleted entry.
+ // use KeyAt(i)->IsTheHole(isolate) to determine if this is a deleted entry.
Object* KeyAt(int entry) {
DCHECK_LT(entry, this->UsedCapacity());

Powered by Google App Engine
This is Rietveld 408576698